#

##

##

###

###

##

###

##

##

##

##

###

###

##

##

##

    		recycling

    		objectives

    			Move the images to another module.

    		on
    			session 1
    				docker compose up -d; docker exec -it recycling.1 bash;
    				. /habitat/_controls/build_1.sh

    			session 2
    				docker exec -it recycling.1 bash;
    				. /habitat/_controls/build_2.sh

    		build
    			mongo

    			??
    				# socketio
    				# eventlet

    		organs
    			instrument
    				cd /habitat/consensus_1
    				recycling_1 instrument layer start --name instrument_1

    			stage
    				cd /habitat/consensus_1
    				recycling_1 stage layer start --name stage_1

    		poetry
    			pip install poetry poetry-plugin-export

    			update

    			installations
    				poetry config virtualenvs.path /path/to/your/directory

    		publishing
    			(cd /habitat/venues/stages/recycling && pycycle --here)

    			python3 /habitat/venues/stages/recycling/_status/status.proc.py
    			python3 /habitat/venues/stages/recycling/__status/status_API.proc.py

    			#
    			#	poetry auth
    			#
    			(pip install poetry && cd /habitat && rm -rf dist && poetry build --format sdist --verbose && chmod -R 777 /habitat && poetry publish --verbose;)

    	important
    		poetry show --tree

    	docker
    		docker network create --subnet=192.168.0.0/24 container_network
    		docker run --network container_network --ip 192.168.0.160 -v .:/recycling -it jumps:v2.1.0
    		docker exec -it 9fd55c2b8034 bash